@@ -11,7 +11,6 @@ pub use solana_program::*;
 
 pub mod account;
 pub mod account_utils;
-pub mod arithmetic;
 pub mod builtins;
 pub mod client;
 pub mod commitment_config;
@@ -21,9 +20,7 @@ pub mod deserialize_utils;
 pub mod ed25519_instruction;
 pub mod entrypoint;
 pub mod entrypoint_deprecated;
-pub mod entrypoint_native;
 pub mod epoch_info;
-pub mod execute_timings;
 pub mod exit;
 pub mod feature;
 pub mod feature_set;
@@ -35,10 +32,9 @@ pub mod keyed_account;
 pub mod log;
 pub mod native_loader;
 pub mod nonce_account;
-pub mod nonce_keyed_account;
 pub mod packet;
 pub mod poh_config;
-pub mod process_instruction;
+pub mod precompiles;
 pub mod program_utils;
 pub mod pubkey;
 pub mod recent_blockhashes_account;
@@ -48,12 +44,13 @@ pub mod shred_version;
 pub mod signature;
 pub mod signer;
 pub mod system_transaction;
-#[doc(hidden)]
-pub mod sysvar_cache;
 pub mod timing;
 pub mod transaction;
 pub mod transport;
+pub mod wasm;
 
+/// Same as `declare_id` except report that this id has been deprecated
+pub use solana_sdk_macro::declare_deprecated_id;
 /// Convenience macro to declare a static public key and functions to interact with it
 ///
 /// Input: a single literal base58 string representation of a program's id
@@ -106,15 +103,6 @@ macro_rules! program_stubs {
     () => {};
 }
 
-/// Convenience macro for `AddAssign` with saturating arithmetic.
-/// Replace by `std::num::Saturating` once stable
-#[macro_export]
-macro_rules! saturating_add_assign {
-    ($i:expr, $v:expr) => {{
-        $i = $i.saturating_add($v)
-    }};
-}
-
 #[macro_use]
 extern crate serde_derive;
 pub extern crate bs58;
@@ -122,18 +110,3 @@ extern crate log as logger;
 
 #[macro_use]
 extern crate solana_frozen_abi_macro;
-
-#[cfg(test)]
-mod tests {
-    #[test]
-    fn test_saturating_add_assign() {
-        let mut i = 0u64;
-        let v = 1;
-        saturating_add_assign!(i, v);
-        assert_eq!(i, 1);
-
-        i = u64::MAX;
-        saturating_add_assign!(i, v);
-        assert_eq!(i, u64::MAX);
-    }
-}
